resource "kubernetes_deployment" "aws_alb_ingress_deployment" {
  metadata {
    name      = "alb-ingress-controller"
    namespace = "kube-system"
  }

  spec {
    replicas = 1

    selector {
      match_labels {
        name = "aws-alb-ingress-controller"
      }
    }

    template {
      metadata {
        name = "aws-alb-ingress-controller"

        annotations {
          iam.amazonaws.com/role = eks-alb-ingress-controller
        }

        labels {
          name = "aws-alb-ingress-controller"
        }
      }

      spec {
        service_account_name             = "aws-alb-svc-acc"
        termination_grace_period_seconds = 60

        volume {
          name = "${kubernetes_service_account.aws_alb_service_account.default_secret_name}"

          secret {
            secret_name = "${kubernetes_service_account.aws_alb_service_account.default_secret_name}"
          }
        }

        container {
          image             = "amazon/aws-alb-ingress-controller:v1.1.2"
          name              = "aws-alb-ingress-container"
          image_pull_policy = "IfNotPresent"
          args              = ["--cluster-name=${var.cluster_name}"]

          volume_mount {
            mount_path = "/var/run/secrets/kubernetes.io/serviceaccount"
            name       = "${kubernetes_service_account.aws_alb_service_account.default_secret_name}"
            read_only  = true
          }

          port {
            name           = "health"
            container_port = 10254
            protocol       = "TCP"
          }
        }
      }
    }
  }
}
